import {Player} from "@prisma/client";
import $ from 'jquery';
import {maxExp, maxHp, maxStamina} from "../../../formulas";
import {progressBar} from "../components";
import {hasStaminaAgain, outOfStamina} from "../dom";

function renderStatText(id: string, value: number, incrementable: boolean) {
  $(`#${id} .text`).html(value.toString());
  if(incrementable) {
    $(`#${id} .stat-increase`).removeClass('hidden');
  }
  else {
    $(`#${id} .stat-increase`).addClass('hidden');
  }
}

export function playerOverview(player: Player) {

  const incrementable = player.statPoints > 0;

  $('#name').html(`${player.username}, Level ${player.level}`);

  renderStatText('pow', player.pow, incrementable);
  renderStatText('zest', player.zest, incrementable);
  renderStatText('woosh', player.woosh, incrementable);
  renderStatText('aha', player.aha, incrementable);
  renderStatText('luck', player.luck, incrementable);
  renderStatText('wow', player.wow, incrementable);
  renderStatText('stp', player.statPoints, incrementable);

  $('#hit .progress-bar-wrapper').html(progressBar(player.hp, maxHp(player.level, player.zest), {
    color: 'danger'
  }));

  $('#sta .progress-bar-wrapper').html(progressBar(player.stamina, maxStamina(player.level, player.woosh), {
    color: 'success'
  }));

  $('#exp .progress-bar-wrapper').html(progressBar(player.exp, maxExp(player.level), {
    color: 'info'
  }));

  if(player.stamina <= 0) {
    outOfStamina();
  }
  else {
    hasStaminaAgain();
  }
}
