import { server } from '../../lib/server';
import { Static, Type } from '@sinclair/typebox';
import { prisma } from '../../lib/db';
import { NotFoundError } from '../../lib/http-errors';
import { v4 as uuid } from 'uuid';
import {Player} from '@prisma/client';

const LoginInput = Type.Object({
  body: Type.Object({
    username: Type.String(),
    password: Type.String()
  })
});

type LoginInputType = Static<typeof LoginInput>;

export type LoginOutputType = {
  token: string,
  player: Player
};

export const login = server.post<LoginInputType, any>('/v1/accounts/auth', {
  schema: LoginInput
}, async req => {
  const {username, password} = req.body;
  const player = await prisma.player.findUnique({
    where: {
      username: username
    }
  });

  if(!player || password !== player.password) { 
    throw new NotFoundError('Invalid user credentials');
  }

  const token = await prisma.authToken.upsert({
    where: {
      playerId: player.id
    },
    create: {
      playerId: player.id
    },
    update: {
      token: uuid()
    }
  });

  return {
    token: token.token,
    player
  };
});
